@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: trifecta
 version: 1.5.2
-id: trifecta-1.5.2-eb1dd4d699e260a8c6e1c779cdeab2db
-key: trife_0DA5J1lYbp54emHKjJmcMH
+id: trifecta-1.5.2-304d5f8a822b060ecc4e65f0538a3930
+key: trife_BplJAd49lVj2qQ3iTQhpCd
 license: BSD3
 copyright: Copyright (C) 2010-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
-hs-libraries: HStrifecta-1.5.2-0DA5J1lYbp54emHKjJmcMH
+hs-libraries: HStrifecta-1.5.2-BplJAd49lVj2qQ3iTQhpCd
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
@@ -37,21 +37,21 @@ depends:
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    charset-0.3.7.1-543137c1a84e9708652346da73519711
-    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
+    charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
+    comonad-5-530ea4e1d08a0115920b946124e760ac
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    lens-4.13.1-0500c41dd5bf4a913992f535a881c76b
+    lens-4.13.2-b1c10d48e79ebd67299af6a45dec3a18
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    parsers-0.12.3-e9ff529474e9ade28ca7d7edafd220d1
-    profunctors-5.2-9bddc68ddf0f4fcea803005a53816983
-    reducers-3.12.1-ea06090a8c66812eff0cd7d6cba6d6c9
-    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    parsers-0.12.3-bc69b9074777600cb88682e376030c1b
+    profunctors-5.2-1b9f80ec12ba976fbd92d616f7b33d0d
+    reducers-3.12.1-70a19f2922707754274d8f14688839b6
+    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
 haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
 haddock-html: /usr/share/doc/haskell-trifecta/html
